capture log close
clear
clear matrix
log using "dd.jcr.log", replace

*************************************************************************
*************************************************************************
* File to run models and calculate quantities of interest for the paper *
*** "Delegating Death: Military Intervention and Government Killing"  ***                                                                
*************************************************************************
* Created by: Jacqueline H.R. DeMeritt 					*
* Created on: 26 April 2008   						*                                  
* Last edited on: 9 August 2012                                         *	                 
*************************************************************************
*************************************************************************

**************************************************
* call data and set seed for future replications *
**************************************************
set mem 800m
use "dd.jcr.dta"
set seed 08221981

**************************************************************
* generate necessary interaction terms, weighted terms, etc. *
**************************************************************
quietly{
gen dvdum=0
replace dvdum=1 if vnc>0 & vnc~=.
replace dvdum=0 if vnc==0
replace dvdum=. if vnc==.
tab dvdum

gen ccodel1=ccode[_n-1]
gen ldvdum=dvdum[_n-1]
replace ldvdum=. if ccode~=ccodel1

gen l1physint2=physint2[_n-1]
replace l1physint2=. if ccode~=ccodel1
gen l2physint2= physint2[_n-2]
replace l2physint2=. if ccode~=ccodel1
gen l3physint2= physint2[_n-3]
replace l3physint2=. if ccode~=ccodel1
gen l4physint2= physint2[_n-4]
replace l4physint2=. if ccode~=ccodel1
gen ma_phys=(physint2+l1physint2+l2physint2)/3
gen ma_phys2=(physint2+l1physint2)/2

gen l1physint2_flip=physint2_flip[_n-1]
replace l1physint2_flip=. if ccode~=ccodel1
gen l2physint2_flip= physint2_flip[_n-2]
replace l2physint2_flip=. if ccode~=ccodel1
gen l3physint2_flip= physint2_flip[_n-3]
replace l3physint2_flip=. if ccode~=ccodel1
gen l4physint2_flip= physint2_flip[_n-4]
replace l4physint2_flip=. if ccode~=ccodel1
gen ma_phys_flip=(physint2_flip+l1physint2_flip+l2physint2_flip)/3
gen ma_phys2_flip=(physint2_flip+l1physint2_flip)/2

* Note: ma_phys is an average of this year, last year, and the year before that. ma_phys2 is an average of this year and last year (physint2)
* These facts remain when CIRI PHYSINT is flipped.

gen openw=openness*w_extend
gen aidw=aid_cap*w_extend
gen cap_intag=capacity*against_gov
gen cap_intsup=capacity*support_gov
gen cap_aid=capacity*aidw
gen cap_open=capacity*openw
gen repress_intag=ma_phys2*against_gov
gen repress_intsup=ma_phys2*support_gov
gen repress_aid=ma_phys2*aidw
gen repress_open=ma_phys2*openw
recode democ -88=. -77=. -66=.
gen politysq=polity2*polity2
}

******************************************
* STEP 1: Heckman (selection) estimation *
******************************************

*drop p1 phi capphi invmills
set more off
probit dvdum democ ldvdum prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt, robust nolog

* Predict Pr(Y=1), calculate phi and the inverse mills ratio from this analysis:
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills= phi/capphi

***************************
* STEP 2: ZINB estimation *
***************************
* ADDITIVE MODEL *
zinb vnc capacity ma_phys2_flip  against_gov support_gov aidw openw   lpop invmills priowar, inflate(capacity ma_phys2_flip  against_gov support_gov aidw openw   invmills priowar) cluster(ccode) nolog

* INTERVENTION AGAINST INTERACTS WITH CAPACITY *
zinb vnc capacity ma_phys2_flip  against_gov support_gov aidw openw  cap_intag lpop invmills priowar, inflate(capacity ma_phys2_flip  against_gov support_gov aidw openw  cap_intag invmills priowar) cluster(ccode) nolog
test [inflate]capacity [inflate]against_gov [inflate]cap_intag
test [vnc]capacity [vnc]against_gov [vnc]cap_intag

log close
log using "dd.jcr.supplement.log", replace

**NOTE: To replicate supplementary and substantive results precisely, all following ZINB models must have priowar added as an IV to both the inflation and NB equations!

**********************************
* Robustness checks for appendix:
**********************************

** Alternate Measures of Democracy: **

*(1) Polity [-10,10]

drop p1 phi capphi
set more off
probit dvdum ldvdum polity2 prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt, robust nolog

* Predict Pr(Y=1), calculate phi and the inverse mills ratio from this analysis:
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills2= phi/capphi

*(2) Polity [-10,10] \geq 6 

drop p1 phi capphi
set more off
gen poldum=.
replace poldum=0 if polity2<6
replace poldum=1 if polity2>=6
replace poldum=. if polity2==.
tab poldum
probit dvdum ldvdum poldum prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt, robust nolog

* Predict Pr(Y=1), calculate phi and the inverse mills ratio from this analysis:
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills3= phi/capphi

*(3) Polity [-10,10] \geq 7 

drop p1 phi capphi
set more off
gen poldum7=.
replace poldum7=0 if polity2<7
replace poldum7=1 if polity2>=7
replace poldum7=. if polity2==.
tab poldum7
probit dvdum ldvdum poldum7 prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt, robust nolog

* Predict Pr(Y=1), calculate phi and the inverse mills ratio from this analysis:
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills4= phi/capphi

*(4) Binary Decomposition of Democracy [0,10]  

drop p1 phi capphi
set more off
xi: probit dvdum ldvdum prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt i.democ, robust nolog
* Predict Pr(Y=1), calculate phi and the inverse mills ratio from this analysis:
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills5= phi/capphi

*(5) Collapsed (linear) scale of Democracy [0,10]
*NOTE: Linear scale is derived from the coefficients on the binary decomposition (above). 
drop p1 phi capphi
set more off
gen dem_linear=.
replace dem_linear=1 if democ==0
replace dem_linear=2 if democ==1 | democ==2 | democ==3
replace dem_linear=3 if democ==4
replace dem_linear=4 if democ==5 
replace dem_linear=5 if democ==6 | democ==7
replace dem_linear=6 if democ==8 | democ==9 | democ==10
tab dem_linear
probit dvdum ldvdum dem_linear prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt, robust nolog

* Predict Pr(Y=1), calculate phi and the inverse mills ratio from this analysis:
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills6= phi/capphi

*(6) Polity [-10,10] & Squared

drop p1 phi capphi
set more off
probit dvdum ldvdum polity2 politysq prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt, robust nolog

* Predict Pr(Y=1), calculate phi and the inverse mills ratio from this analysis:
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills7= phi/capphi

*(7) Selectorate Size 

drop p1 phi capphi
set more off
gen w_o_s=w_extend/s
probit dvdum ldvdum w_o_s prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt, robust nolog

* Predict Pr(Y=1), calculate phi and the inverse mills ratio from this analysis:
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills8= phi/capphi

** Correlations among measures of democ (wrt IMR):
corr invmills*

*Accept HR Treaty Regime?
******************************************
* STEP 1: Heckman (selection) estimation *
******************************************

drop p1 phi capphi invmills*
set more off
probit dvdum ldvdum prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt democ, robust nolog

* Predict Pr(Y=1), calculate phi and the inverse mills ratio from this analysis:
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills= phi/capphi

***************************
* STEP 2: ZINB estimation *
***************************
* ADDITIVE MODEL *
zinb vnc capacity ma_phys2_flip  against_gov support_gov aidw openw   lpop invmills, inflate(capacity ma_phys2_flip  against_gov support_gov aidw openw   invmills) cluster(ccode) nolog

* INTERVENTION AGAINST INTERACTS WITH CAPACITY *
zinb vnc capacity ma_phys2_flip  against_gov support_gov aidw openw  cap_intag lpop invmills, inflate(capacity ma_phys2_flip  against_gov support_gov aidw openw  cap_intag invmills) cluster(ccode) nolog
test [inflate]capacity [inflate]against_gov [inflate]cap_intag
test [vnc]capacity [vnc]against_gov [vnc]cap_intag

log close
log using "dd.substantive.in-sample.log", replace
**NOTE: To replicate supplementary and substantive results precisely, all that follows must have priowar added as an IV to both the inflation and NB equations!

**************************************************************
**************************************************************
* SUBSTANTIVE IMPACTS OF INTERVENTION AGAINST THE GOVERNMENT *
**************************************************************
**************************************************************
quietly{
drop p1 phi capphi invmills
set more off
probit dvdum ldvdum prioiwar inter_attrition inter_annex priocw guerr gthreat hicivsup lickidnt democ, robust nolog
predict p1 if e(sample)==1, xb
generate phi = (1/sqrt(2*_pi))*exp(-(p1^2/2))  
generate capphi = normal(p1)
generate invmills= phi/capphi
zinb vnc capacity ma_phys2_flip  against_gov support_gov aidw openw  cap_intag lpop invmills priowar, inflate(capacity ma_phys2_flip  against_gov support_gov aidw  openw  cap_intag invmills priowar) cluster(ccode) nolog
sum capacity ma_phys2_flip  against_gov support_gov aidw openw  lpop invmills if e(sample)==1
}
********************************************
* Intervention against moderates capacity? *
********************************************
quietly{
*** Intervention Against = 0, capacity varies ***

gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.02
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.02
gen pzero002 = exp(a2)/(1+exp(a2))
gen pcount002 = exp(a1)*(1-pzero002)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.04
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.04
gen pzero004 = exp(a2)/(1+exp(a2))
gen pcount004 = exp(a1)*(1-pzero004)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.06
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.06
gen pzero006 = exp(a2)/(1+exp(a2))
gen pcount006 = exp(a1)*(1-pzero006)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.08
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.08
gen pzero008 = exp(a2)/(1+exp(a2))
gen pcount008 = exp(a1)*(1-pzero008)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.10
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.10
gen pzero010 = exp(a2)/(1+exp(a2))
gen pcount010 = exp(a1)*(1-pzero010)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.12
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.12
gen pzero012 = exp(a2)/(1+exp(a2))
gen pcount012 = exp(a1)*(1-pzero012)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.14
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.14
gen pzero014 = exp(a2)/(1+exp(a2))
gen pcount014 = exp(a1)*(1-pzero014)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.16
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.16
gen pzero016 = exp(a2)/(1+exp(a2))
gen pcount016 = exp(a1)*(1-pzero016)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.18
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.18
gen pzero018 = exp(a2)/(1+exp(a2))
gen pcount018 = exp(a1)*(1-pzero018)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.20
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.20
gen pzero020 = exp(a2)/(1+exp(a2))
gen pcount020 = exp(a1)*(1-pzero020)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.22
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.22
gen pzero022 = exp(a2)/(1+exp(a2))
gen pcount022 = exp(a1)*(1-pzero022)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.24
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.24
gen pzero024 = exp(a2)/(1+exp(a2))
gen pcount024 = exp(a1)*(1-pzero024)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.26
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.26
gen pzero026 = exp(a2)/(1+exp(a2))
gen pcount026 = exp(a1)*(1-pzero026)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.28
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.28
gen pzero028 = exp(a2)/(1+exp(a2))
gen pcount028 = exp(a1)*(1-pzero028)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.30
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.30
gen pzero030 = exp(a2)/(1+exp(a2))
gen pcount030 = exp(a1)*(1-pzero030)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.32
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.32
gen pzero032 = exp(a2)/(1+exp(a2))
gen pcount032 = exp(a1)*(1-pzero032)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.34
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.34
gen pzero034 = exp(a2)/(1+exp(a2))
gen pcount034 = exp(a1)*(1-pzero034)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.36
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.36
gen pzero036 = exp(a2)/(1+exp(a2))
gen pcount036 = exp(a1)*(1-pzero036)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.38
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.38
gen pzero038 = exp(a2)/(1+exp(a2))
gen pcount038 = exp(a1)*(1-pzero038)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.40
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.40
gen pzero040 = exp(a2)/(1+exp(a2))
gen pcount040 = exp(a1)*(1-pzero040)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.42
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.42
gen pzero042 = exp(a2)/(1+exp(a2))
gen pcount042 = exp(a1)*(1-pzero042)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.44
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.44
gen pzero044 = exp(a2)/(1+exp(a2))
gen pcount044 = exp(a1)*(1-pzero044)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.46
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.46
gen pzero046 = exp(a2)/(1+exp(a2))
gen pcount046 = exp(a1)*(1-pzero046)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.48
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.48
gen pzero048 = exp(a2)/(1+exp(a2))
gen pcount048 = exp(a1)*(1-pzero048)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.50
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.50
gen pzero050 = exp(a2)/(1+exp(a2))
gen pcount050 = exp(a1)*(1-pzero050)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.52
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.52
gen pzero052 = exp(a2)/(1+exp(a2))
gen pcount052 = exp(a1)*(1-pzero052)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.54
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.54
gen pzero054 = exp(a2)/(1+exp(a2))
gen pcount054 = exp(a1)*(1-pzero054)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.56
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.56
gen pzero056 = exp(a2)/(1+exp(a2))
gen pcount056 = exp(a1)*(1-pzero056)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.58
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.58
gen pzero058 = exp(a2)/(1+exp(a2))
gen pcount058 = exp(a1)*(1-pzero058)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.60
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.60
gen pzero060 = exp(a2)/(1+exp(a2))
gen pcount060 = exp(a1)*(1-pzero060)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.62
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.62
gen pzero062 = exp(a2)/(1+exp(a2))
gen pcount062 = exp(a1)*(1-pzero062)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.64
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.64
gen pzero064 = exp(a2)/(1+exp(a2))
gen pcount064 = exp(a1)*(1-pzero064)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.66
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.66
gen pzero066 = exp(a2)/(1+exp(a2))
gen pcount066 = exp(a1)*(1-pzero066)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.68
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.68
gen pzero068 = exp(a2)/(1+exp(a2))
gen pcount068 = exp(a1)*(1-pzero068)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.70
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.70
gen pzero070 = exp(a2)/(1+exp(a2))
gen pcount070 = exp(a1)*(1-pzero070)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.72
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.72
gen pzero072 = exp(a2)/(1+exp(a2))
gen pcount072 = exp(a1)*(1-pzero072)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.74
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.74
gen pzero074 = exp(a2)/(1+exp(a2))
gen pcount074 = exp(a1)*(1-pzero074)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.76
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.76
gen pzero076 = exp(a2)/(1+exp(a2))
gen pcount076 = exp(a1)*(1-pzero076)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.78
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.78
gen pzero078 = exp(a2)/(1+exp(a2))
gen pcount078 = exp(a1)*(1-pzero078)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.80
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.80
gen pzero080 = exp(a2)/(1+exp(a2))
gen pcount080 = exp(a1)*(1-pzero080)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.82
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.82
gen pzero082 = exp(a2)/(1+exp(a2))
gen pcount082 = exp(a1)*(1-pzero082)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.84
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.84
gen pzero084 = exp(a2)/(1+exp(a2))
gen pcount084 = exp(a1)*(1-pzero084)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.86
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.86
gen pzero086 = exp(a2)/(1+exp(a2))
gen pcount086 = exp(a1)*(1-pzero086)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.88
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.88
gen pzero088 = exp(a2)/(1+exp(a2))
gen pcount088 = exp(a1)*(1-pzero088)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.90
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.90
gen pzero090 = exp(a2)/(1+exp(a2))
gen pcount090 = exp(a1)*(1-pzero090)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.92
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.92
gen pzero092 = exp(a2)/(1+exp(a2))
gen pcount092 = exp(a1)*(1-pzero092)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.94
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.94
gen pzero094 = exp(a2)/(1+exp(a2))
gen pcount094 = exp(a1)*(1-pzero094)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*0 +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*0 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.96
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*0+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*0 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.96
gen pzero096 = exp(a2)/(1+exp(a2))
gen pcount096 = exp(a1)*(1-pzero096)

*** Intervention Against = 1, capacity varies from .02 to .40 ***
drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.02) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.02
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.02)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.02
gen pzero102 = exp(a2)/(1+exp(a2))
gen pcount102 = exp(a1)*(1-pzero102)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.04) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.04
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.04)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.04
gen pzero104 = exp(a2)/(1+exp(a2))
gen pcount104 = exp(a1)*(1-pzero104)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.06) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.06
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.06)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.06
gen pzero106 = exp(a2)/(1+exp(a2))
gen pcount106 = exp(a1)*(1-pzero106)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.08) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.08
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.08)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.08
gen pzero108 = exp(a2)/(1+exp(a2))
gen pcount108 = exp(a1)*(1-pzero108)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.10) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.10
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.10)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.10
gen pzero110 = exp(a2)/(1+exp(a2))
gen pcount110 = exp(a1)*(1-pzero110)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.12) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.12
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.12)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.12
gen pzero112 = exp(a2)/(1+exp(a2))
gen pcount112 = exp(a1)*(1-pzero112)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.14) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.14
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.14)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.14
gen pzero114 = exp(a2)/(1+exp(a2))
gen pcount114 = exp(a1)*(1-pzero114)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.16) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.16
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.16)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.16
gen pzero116 = exp(a2)/(1+exp(a2))
gen pcount116 = exp(a1)*(1-pzero116)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.18) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.18
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.18)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.18
gen pzero118 = exp(a2)/(1+exp(a2))
gen pcount118 = exp(a1)*(1-pzero118)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.20) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.20
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.20)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.20
gen pzero120 = exp(a2)/(1+exp(a2))
gen pcount120 = exp(a1)*(1-pzero120)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.22) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.22
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.22)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.22
gen pzero122 = exp(a2)/(1+exp(a2))
gen pcount122 = exp(a1)*(1-pzero122)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.24) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.24
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.24)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.24
gen pzero124 = exp(a2)/(1+exp(a2))
gen pcount124 = exp(a1)*(1-pzero124)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.26) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.26
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.26)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.26
gen pzero126 = exp(a2)/(1+exp(a2))
gen pcount126 = exp(a1)*(1-pzero126)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.28) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.28
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.28)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.28
gen pzero128 = exp(a2)/(1+exp(a2))
gen pcount128 = exp(a1)*(1-pzero128)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.30) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.30
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.30)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.30
gen pzero130 = exp(a2)/(1+exp(a2))
gen pcount130 = exp(a1)*(1-pzero130)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.32) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.32
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.32)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.32
gen pzero132 = exp(a2)/(1+exp(a2))
gen pcount132 = exp(a1)*(1-pzero132)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.34) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.34
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.34)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.34
gen pzero134 = exp(a2)/(1+exp(a2))
gen pcount134 = exp(a1)*(1-pzero134)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.36) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.36
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.36)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.36
gen pzero136 = exp(a2)/(1+exp(a2))
gen pcount136 = exp(a1)*(1-pzero136)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.38) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.38
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.38)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.38
gen pzero138 = exp(a2)/(1+exp(a2))
gen pcount138 = exp(a1)*(1-pzero138)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.40) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.40
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.40)+  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.40
gen pzero140 = exp(a2)/(1+exp(a2))
gen pcount140 = exp(a1)*(1-pzero140)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.42) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.42
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.42) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.42
gen pzero142 = exp(a2)/(1+exp(a2))
gen pcount142 = exp(a1)*(1-pzero142)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.44) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.44
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.44) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.44
gen pzero144 = exp(a2)/(1+exp(a2))
gen pcount144 = exp(a1)*(1-pzero144)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.46) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.46
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.46) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.46
gen pzero146 = exp(a2)/(1+exp(a2))
gen pcount146 = exp(a1)*(1-pzero146)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.48) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.48
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.48) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.48
gen pzero148 = exp(a2)/(1+exp(a2))
gen pcount148 = exp(a1)*(1-pzero148)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.50) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.50
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.50) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.50
gen pzero150 = exp(a2)/(1+exp(a2))
gen pcount150 = exp(a1)*(1-pzero150)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.52) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.52
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.52) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.52
gen pzero152 = exp(a2)/(1+exp(a2))
gen pcount152 = exp(a1)*(1-pzero152)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.54) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.54
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.54) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.54
gen pzero154 = exp(a2)/(1+exp(a2))
gen pcount154 = exp(a1)*(1-pzero154)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.56) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.56
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.56) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.56
gen pzero156 = exp(a2)/(1+exp(a2))
gen pcount156 = exp(a1)*(1-pzero156)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.58) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.58
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.58) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.58
gen pzero158 = exp(a2)/(1+exp(a2))
gen pcount158 = exp(a1)*(1-pzero158)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.60) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.60
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.60) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.60
gen pzero160 = exp(a2)/(1+exp(a2))
gen pcount160 = exp(a1)*(1-pzero160)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.62) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.62
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.62) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.62
gen pzero162 = exp(a2)/(1+exp(a2))
gen pcount162 = exp(a1)*(1-pzero162)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.64) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.64
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.64) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.64
gen pzero164 = exp(a2)/(1+exp(a2))
gen pcount164 = exp(a1)*(1-pzero164)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.66) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.66
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.66) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.66
gen pzero166 = exp(a2)/(1+exp(a2))
gen pcount166 = exp(a1)*(1-pzero166)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.68) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.68
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.68) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.68
gen pzero168 = exp(a2)/(1+exp(a2))
gen pcount168 = exp(a1)*(1-pzero168)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.70) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.70
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.70) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.70
gen pzero170 = exp(a2)/(1+exp(a2))
gen pcount170 = exp(a1)*(1-pzero170)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.72) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.72
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.72) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.72
gen pzero172 = exp(a2)/(1+exp(a2))
gen pcount172 = exp(a1)*(1-pzero172)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.74) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.74
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.74) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.74
gen pzero174 = exp(a2)/(1+exp(a2))
gen pcount174 = exp(a1)*(1-pzero174)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.76) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.76
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.76) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.76
gen pzero176 = exp(a2)/(1+exp(a2))
gen pcount176 = exp(a1)*(1-pzero176)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.78) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.78
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.78) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.78
gen pzero178 = exp(a2)/(1+exp(a2))
gen pcount178 = exp(a1)*(1-pzero178)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.80) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.80
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.80) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.80
gen pzero180 = exp(a2)/(1+exp(a2))
gen pcount180 = exp(a1)*(1-pzero180)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.82) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.82
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.82) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.82
gen pzero182 = exp(a2)/(1+exp(a2))
gen pcount182 = exp(a1)*(1-pzero182)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.84) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.84
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.84) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.84
gen pzero184 = exp(a2)/(1+exp(a2))
gen pcount184 = exp(a1)*(1-pzero184)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.86) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.86
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.86) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.86
gen pzero186 = exp(a2)/(1+exp(a2))
gen pcount186 = exp(a1)*(1-pzero186)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.88) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.88
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.88) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.88
gen pzero188 = exp(a2)/(1+exp(a2))
gen pcount188 = exp(a1)*(1-pzero188)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.90) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.90
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.90) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.90
gen pzero190 = exp(a2)/(1+exp(a2))
gen pcount190 = exp(a1)*(1-pzero190)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.92) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.92
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.92) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.92
gen pzero192 = exp(a2)/(1+exp(a2))
gen pcount192 = exp(a1)*(1-pzero192)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.94) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.94
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.94) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.94
gen pzero194 = exp(a2)/(1+exp(a2))
gen pcount194 = exp(a1)*(1-pzero194)

drop a1 a2
gen a1 = _b[vnc:_cons] + _b[vnc:invmills]*invmills + _b[vnc:lpop]*lpop + _b[vnc:cap_intag]*(1*.96) +  _b[vnc:aidw]*aidw + _b[vnc:openw]*openw +  _b[vnc:support_gov]*support_gov + _b[vnc:against_gov]*1 +  _b[vnc:ma_phys2_flip]*ma_phys2_flip + _b[vnc:capacity]*.96
gen a2 = _b[inflate:_cons] + _b[inflate:invmills]*invmills + _b[inflate:cap_intag]*(1*.96) +  _b[inflate:aidw]*aidw + _b[inflate:openw]*openw +  _b[inflate:support_gov]*support_gov + _b[inflate:against_gov]*1 +  _b[inflate:ma_phys2_flip]*ma_phys2_flip + _b[inflate:capacity]*.96
gen pzero196 = exp(a2)/(1+exp(a2))
gen pcount196 = exp(a1)*(1-pzero196)
}
*** Effects on E(Death Toll) when Intervention Against is Absent, Capacity Varies: ***
ci pcount0*
*** Effects on E(Death Toll) when Intervention Against is Present, Capacity Varies: ***
ci pcount1*

*** Effects on Pr(Can't Kill) when Intervention Against is Absent, Capacity Varies: ***
ci pzero0*
*** Effects on Pr(Can't Kill) when Intervention Against is Present, Capacity Varies: ***
ci pzero1*


log close


